@@ -108,15 +108,18 @@ class MapLoader(object):
             structure = MMCIFParser().get_structure(self.mobj.pdb_code, self._filepath)
         else:
             structure = PDBParser(PERMISSIVE=True).get_structure(self.mobj.pdb_code, self._filepath)                
+            found_em = False
             with open(self._filepath,"r") as fr:
                 lines = fr.readlines()
                 for line in lines:
                     self.pobj.add_line_string(line)
                     #REMARK 900 RELATED ID: EMD-6240   RELATED DB: EMDB                              
-                    if "REMARK 900 RELATED ID:" in line and "EMD-" in line:
+                    if "REMARK 900 RELATED ID:" in line and "EMD-" in line and not found_em:
+                        found_em=True
                         info = line.split(" ")
                         self.em_code = info[4]
                         self.has_both = False
+                        self.mobj.em_link = f"https://www.ebi.ac.uk/emdb/{self.em_code}"
                 
         self._struc_dict = MMCIF2Dict(self._filepath)
         self.mobj.resolution = structure.header["resolution"]
