@@ -20,13 +20,13 @@ class PdbObject(object):
         atm1, atm2, atm3 = {},{},{}
         count = 0
         for atm in self.lines:
-            if atm["atm"] == "CA":
+            if atm["atm"] == "CA" and (atm["version"] == "A" or atm["version"] == ""):
                 atm1 = atm
                 count += 1
-            elif atm["atm"] == "C":
+            elif atm["atm"] == "C" and (atm["version"] == "A" or atm["version"] == ""):
                 atm2 = atm
                 count += 1
-            elif atm["atm"] == "O":
+            elif atm["atm"] == "O" and (atm["version"] == "A" or atm["version"] == ""):
                 atm3 = atm
                 count += 1
             if count == 3:
